.. :changelog:

History
-------

0.1 (14-04-2017)
---------------------

* First release on pypi


0.1.1 (07-07-2021)
------------------

* Updated template, bumped dependencies and implemented a pipeline.
